@@ -6,17 +6,19 @@ using System.Reflection;
 using System.Runtime.InteropServices;
 using Mono.Unix;
 
-// Work around bug in Gtk# panel applet bindings by using a local copy with
-// fixed OnBackgroundChanged marshalling.
+#if FIXED_PANELAPPLET
+using Gnome;
+#else
 using _Gnome;
+#endif
 
 namespace Tomboy
 {
 	public class TomboyApplet : PanelApplet
 	{
 		NoteManager manager;
-		TomboyAppletEventBox applet_event_box;
-		TomboyGConfXKeybinder keybinder;
+		TomboyPanelAppletEventBox applet_event_box;
+		TomboyPrefsKeybinder keybinder;
 
 		// Keep referenced so our callbacks don't get reaped.
 		static BonoboUIVerb [] menu_verbs;
@@ -45,8 +47,8 @@ namespace Tomboy
 			Logger.Log ("Applet Created...");
 
 			manager = Tomboy.DefaultNoteManager;
-			applet_event_box = new TomboyAppletEventBox (manager);
-			keybinder = new TomboyGConfXKeybinder (manager, applet_event_box.Tray);
+			applet_event_box = new TomboyPanelAppletEventBox (manager);
+			keybinder = new TomboyPrefsKeybinder (manager, applet_event_box);
 
 			Flags |= PanelAppletFlags.ExpandMinor;
 
@@ -57,6 +59,7 @@ namespace Tomboy
 
 			if (menu_verbs == null) {
 				menu_verbs = new BonoboUIVerb [] {
+					new BonoboUIVerb ("Sync", SyncVerb),
 					new BonoboUIVerb ("Props", ShowPreferencesVerb),
 					new BonoboUIVerb ("Help", ShowHelpVerb),
 					new BonoboUIVerb ("About", ShowAboutVerb)
@@ -84,6 +87,11 @@ namespace Tomboy
 			}
 		}
 
+		void SyncVerb ()
+		{
+			Tomboy.ActionManager ["NoteSynchronizationAction"].Activate ();
+		}
+
 		void ShowPreferencesVerb ()
 		{
 			Tomboy.ActionManager ["ShowPreferencesAction"].Activate ();
@@ -93,7 +101,7 @@ namespace Tomboy
 		{
 			// Don't use the ActionManager in this case because
 			// the handler won't know about the Screen.
-			GuiUtils.ShowHelp ("tomboy.xml", null, Screen, null);
+			GuiUtils.ShowHelp ("ghelp:tomboy", Screen, null);
 		}
 
 		void ShowAboutVerb ()
@@ -137,7 +145,7 @@ namespace Tomboy
 	
 	public enum PanelOrientation { Horizontal, Vertical };
 	
-	public class TomboyAppletEventBox : Gtk.EventBox
+	public class TomboyPanelAppletEventBox : Gtk.EventBox, ITomboyTray
 	{
 		NoteManager manager;
 		TomboyTray tray;
@@ -145,7 +153,7 @@ namespace Tomboy
 		Gtk.Image image;
 		int panel_size;
 
-		public TomboyAppletEventBox (NoteManager manager)
+		public TomboyPanelAppletEventBox (NoteManager manager)
 : base ()
 		{
 			this.manager = manager;
@@ -397,6 +405,24 @@ namespace Tomboy
 
 			InitPixbuf ();
 		}
+
+		public bool MenuOpensUpward ()
+		{
+			bool open_upwards = false;
+			int val = 0;
+			Gdk.Screen screen = null;
+
+			int x, y;
+			GdkWindow.GetOrigin (out x, out y);
+			val = y;
+			screen = Screen;
+
+			Gtk.Requisition menu_req = tray.TomboyTrayMenu.SizeRequest ();
+			if (val + menu_req.Height >= screen.Height)
+				open_upwards = true;
+
+			return open_upwards;
+		}
 	}
 }
 
